/*
**	This file is automatically generated.  Do not edit it by hand.
**/

/*
 * Bit vectors for each control. The entries in the vector correspond
 * to each class.
 */

/* sym_k_DtEditor_object */
static unsigned char object_class_vec1[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_DtHelpDialog_object */
static unsigned char object_class_vec2[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_DtHelpQuickDialog_object */
static unsigned char object_class_vec3[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_DtMenuButton_object */
static unsigned char object_class_vec4[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_DtPrintSetupBox_object */
static unsigned char object_class_vec5[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_DtPrintSetupDialog_object */
static unsigned char object_class_vec6[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_DtTerm_object */
static unsigned char object_class_vec7[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_DtTermPrimitive_object */
static unsigned char object_class_vec8[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmArrowButton_object */
static unsigned char object_class_vec9[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmArrowButtonGadget_object */
static unsigned char object_class_vec10[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmBulletinBoard_object */
static unsigned char object_class_vec11[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmBulletinBoardDialog_object */
static unsigned char object_class_vec12[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmButtonBox_object */
static unsigned char object_class_vec13[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmCascadeButton_object */
static unsigned char object_class_vec14[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmCascadeButtonGadget_object */
static unsigned char object_class_vec15[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmCheckBox_object */
static unsigned char object_class_vec16[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmColorSelector_object */
static unsigned char object_class_vec17[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmColumn_object */
static unsigned char object_class_vec18[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmComboBox_object */
static unsigned char object_class_vec19[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmCommand_object */
static unsigned char object_class_vec20[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmCommandDialog_object */
static unsigned char object_class_vec21[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmContainer_object */
static unsigned char object_class_vec22[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmDataField_object */
static unsigned char object_class_vec23[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmDialogShell_object */
static unsigned char object_class_vec24[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmDrawingArea_object */
static unsigned char object_class_vec25[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmDrawnButton_object */
static unsigned char object_class_vec26[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmDropDown_object */
static unsigned char object_class_vec27[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmErrorDialog_object */
static unsigned char object_class_vec28[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmFileSelectionBox_object */
static unsigned char object_class_vec29[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmFileSelectionDialog_object */
static unsigned char object_class_vec30[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmFontSelector_object */
static unsigned char object_class_vec31[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmForm_object */
static unsigned char object_class_vec32[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmFormDialog_object */
static unsigned char object_class_vec33[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmFrame_object */
static unsigned char object_class_vec34[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmIconBox_object */
static unsigned char object_class_vec35[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmIconButton_object */
static unsigned char object_class_vec36[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmIconGadget_object */
static unsigned char object_class_vec37[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmInformationDialog_object */
static unsigned char object_class_vec38[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmLabel_object */
static unsigned char object_class_vec39[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmLabelGadget_object */
static unsigned char object_class_vec40[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmList_object */
static unsigned char object_class_vec41[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmMainWindow_object */
static unsigned char object_class_vec42[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmMenuBar_object */
static unsigned char object_class_vec43[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmMenuShell_object */
static unsigned char object_class_vec44[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmMessageBox_object */
static unsigned char object_class_vec45[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmMessageDialog_object */
static unsigned char object_class_vec46[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmMultiList_object */
static unsigned char object_class_vec47[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmNotebook_object */
static unsigned char object_class_vec48[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmOptionMenu_object */
static unsigned char object_class_vec49[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmOutline_object */
static unsigned char object_class_vec50[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmPaned_object */
static unsigned char object_class_vec51[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmPanedWindow_object */
static unsigned char object_class_vec52[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmPopupMenu_object */
static unsigned char object_class_vec53[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmArrowButton_object) |
  _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommand_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDrawnButton_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  _BIT_MASK(sym_k_XmFontSelector_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmIconButton_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmPushButton_object) |
  _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrollBar_object) |
  _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  _BIT_MASK(sym_k_XmSeparator_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTearOffButton_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmToggleButton_object) |
  _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmPromptDialog_object */
static unsigned char object_class_vec54[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmPulldownMenu_object */
static unsigned char object_class_vec55[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  _BIT_MASK(sym_k_XmCascadeButton_object) |
  _BIT_MASK(sym_k_XmCascadeButtonGadget_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOptionMenu_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmPushButton_object */
static unsigned char object_class_vec56[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmPushButtonGadget_object */
static unsigned char object_class_vec57[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmQuestionDialog_object */
static unsigned char object_class_vec58[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmRadioBox_object */
static unsigned char object_class_vec59[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmRenderTable_object */
static unsigned char object_class_vec60[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtMenuButton_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconGadget_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  _BIT_MASK(sym_k_XmLabel_object) |
  0, _BIT_MASK(sym_k_XmLabelGadget_object) |
  _BIT_MASK(sym_k_XmList_object) |
  _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledList_object) |
  _BIT_MASK(sym_k_XmScrolledText_object) |
  _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmText_object) |
  _BIT_MASK(sym_k_XmTextField_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmRendition_object */
static unsigned char object_class_vec61[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRenderTable_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmRowColumn_object */
static unsigned char object_class_vec62[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuShell_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmScale_object */
static unsigned char object_class_vec63[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmScrollBar_object */
static unsigned char object_class_vec64[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmScrolledList_object */
static unsigned char object_class_vec65[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmScrolledText_object */
static unsigned char object_class_vec66[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmScrolledWindow_object */
static unsigned char object_class_vec67[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmSelectionBox_object */
static unsigned char object_class_vec68[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmSelectionDialog_object */
static unsigned char object_class_vec69[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmSeparator_object */
static unsigned char object_class_vec70[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmSeparatorGadget_object */
static unsigned char object_class_vec71[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmSimpleSpinBox_object */
static unsigned char object_class_vec72[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmSpinBox_object */
static unsigned char object_class_vec73[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmTab_object */
static unsigned char object_class_vec74[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmTabList_object) |
  0, 0, 0};

/* sym_k_XmTabBox_object */
static unsigned char object_class_vec75[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmTabList_object */
static unsigned char object_class_vec76[] =
  {
  0, 0, 0, 0, 0, 0, 0, _BIT_MASK(sym_k_XmRendition_object) |
  0, 0, 0, 0, 0};

/* sym_k_XmTabStack_object */
static unsigned char object_class_vec77[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmTearOffButton_object */
static unsigned char object_class_vec78[] =
  {
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0};

/* sym_k_XmTemplateDialog_object */
static unsigned char object_class_vec79[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmText_object */
static unsigned char object_class_vec80[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  _BIT_MASK(sym_k_XmMultiList_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmTextField_object */
static unsigned char object_class_vec81[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmDropDown_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSimpleSpinBox_object) |
  _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmToggleButton_object */
static unsigned char object_class_vec82[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColorSelector_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmToggleButtonGadget_object */
static unsigned char object_class_vec83[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmTree_object */
static unsigned char object_class_vec84[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmWarningDialog_object */
static unsigned char object_class_vec85[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmWorkArea_object */
static unsigned char object_class_vec86[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDialogShell_object) |
  _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_XmWorkingDialog_object */
static unsigned char object_class_vec87[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/* sym_k_user_defined_object */
static unsigned char object_class_vec88[] =
  {
  _BIT_MASK(sym_k_DtEditor_object) |
  _BIT_MASK(sym_k_DtHelpDialog_object) |
  _BIT_MASK(sym_k_DtHelpQuickDialog_object) |
  _BIT_MASK(sym_k_DtPrintSetupBox_object) |
  _BIT_MASK(sym_k_DtPrintSetupDialog_object) |
  0, _BIT_MASK(sym_k_XmBulletinBoard_object) |
  _BIT_MASK(sym_k_XmBulletinBoardDialog_object) |
  _BIT_MASK(sym_k_XmButtonBox_object) |
  0, _BIT_MASK(sym_k_XmCheckBox_object) |
  _BIT_MASK(sym_k_XmColumn_object) |
  _BIT_MASK(sym_k_XmComboBox_object) |
  _BIT_MASK(sym_k_XmCommandDialog_object) |
  _BIT_MASK(sym_k_XmContainer_object) |
  0, _BIT_MASK(sym_k_XmDrawingArea_object) |
  _BIT_MASK(sym_k_XmErrorDialog_object) |
  _BIT_MASK(sym_k_XmFileSelectionBox_object) |
  _BIT_MASK(sym_k_XmFileSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmForm_object) |
  _BIT_MASK(sym_k_XmFormDialog_object) |
  _BIT_MASK(sym_k_XmFrame_object) |
  _BIT_MASK(sym_k_XmIconBox_object) |
  _BIT_MASK(sym_k_XmInformationDialog_object) |
  0, _BIT_MASK(sym_k_XmMainWindow_object) |
  _BIT_MASK(sym_k_XmMenuBar_object) |
  _BIT_MASK(sym_k_XmMessageBox_object) |
  _BIT_MASK(sym_k_XmMessageDialog_object) |
  0, _BIT_MASK(sym_k_XmNotebook_object) |
  _BIT_MASK(sym_k_XmOutline_object) |
  _BIT_MASK(sym_k_XmPaned_object) |
  _BIT_MASK(sym_k_XmPanedWindow_object) |
  _BIT_MASK(sym_k_XmPopupMenu_object) |
  _BIT_MASK(sym_k_XmPromptDialog_object) |
  _BIT_MASK(sym_k_XmPulldownMenu_object) |
  0, _BIT_MASK(sym_k_XmQuestionDialog_object) |
  _BIT_MASK(sym_k_XmRadioBox_object) |
  _BIT_MASK(sym_k_XmRowColumn_object) |
  _BIT_MASK(sym_k_XmScale_object) |
  0, _BIT_MASK(sym_k_XmScrolledWindow_object) |
  _BIT_MASK(sym_k_XmSelectionBox_object) |
  _BIT_MASK(sym_k_XmSelectionDialog_object) |
  0, _BIT_MASK(sym_k_XmSpinBox_object) |
  _BIT_MASK(sym_k_XmTabStack_object) |
  _BIT_MASK(sym_k_XmTemplateDialog_object) |
  0, _BIT_MASK(sym_k_XmTree_object) |
  _BIT_MASK(sym_k_XmWarningDialog_object) |
  _BIT_MASK(sym_k_XmWorkArea_object) |
  _BIT_MASK(sym_k_XmWorkingDialog_object) |
  0, _BIT_MASK(sym_k_user_defined_object) |
  0};

/*
 * Table of bit vectors accessed by sym_k_..._object
 */
static unsigned char *allowed_control_table_vec[] =
  {
  NULL,	/* UNUSED */
  object_class_vec1,
  object_class_vec2,
  object_class_vec3,
  object_class_vec4,
  object_class_vec5,
  object_class_vec6,
  object_class_vec7,
  object_class_vec8,
  object_class_vec9,
  object_class_vec10,
  object_class_vec11,
  object_class_vec12,
  object_class_vec13,
  object_class_vec14,
  object_class_vec15,
  object_class_vec16,
  object_class_vec17,
  object_class_vec18,
  object_class_vec19,
  object_class_vec20,
  object_class_vec21,
  object_class_vec22,
  object_class_vec23,
  object_class_vec24,
  object_class_vec25,
  object_class_vec26,
  object_class_vec27,
  object_class_vec28,
  object_class_vec29,
  object_class_vec30,
  object_class_vec31,
  object_class_vec32,
  object_class_vec33,
  object_class_vec34,
  object_class_vec35,
  object_class_vec36,
  object_class_vec37,
  object_class_vec38,
  object_class_vec39,
  object_class_vec40,
  object_class_vec41,
  object_class_vec42,
  object_class_vec43,
  object_class_vec44,
  object_class_vec45,
  object_class_vec46,
  object_class_vec47,
  object_class_vec48,
  object_class_vec49,
  object_class_vec50,
  object_class_vec51,
  object_class_vec52,
  object_class_vec53,
  object_class_vec54,
  object_class_vec55,
  object_class_vec56,
  object_class_vec57,
  object_class_vec58,
  object_class_vec59,
  object_class_vec60,
  object_class_vec61,
  object_class_vec62,
  object_class_vec63,
  object_class_vec64,
  object_class_vec65,
  object_class_vec66,
  object_class_vec67,
  object_class_vec68,
  object_class_vec69,
  object_class_vec70,
  object_class_vec71,
  object_class_vec72,
  object_class_vec73,
  object_class_vec74,
  object_class_vec75,
  object_class_vec76,
  object_class_vec77,
  object_class_vec78,
  object_class_vec79,
  object_class_vec80,
  object_class_vec81,
  object_class_vec82,
  object_class_vec83,
  object_class_vec84,
  object_class_vec85,
  object_class_vec86,
  object_class_vec87,
  object_class_vec88,
  };
externaldef(uil_sym_glbl) unsigned char **allowed_control_table =
		allowed_control_table_vec;
